from pywiner.system.process import exec_vbs
import sys

def msgbox(icon="information", title="Pywiner", content=""):
    """
    Displays a native Windows message box.

    Args:
        icon (str): The icon to display.
                    Possible values: "information", "warning", "critical".
        title (str): The title of the message box window.
        content (str): The main message content of the box.
    """
    
    # Map friendly icon names to VBScript integer values
    icons = {
        "information": 64,  # vbInformation
        "warning": 48,      # vbExclamation
        "critical": 16      # vbCritical
    }

    vbs_icon_value = icons.get(icon.lower(), 64) # Default to information if not found

    # Sanitize inputs to prevent VBScript errors with quotes
    clean_content = str(content).replace('"', '""')
    clean_title = str(title).replace('"', '""')

    # Construct the VBScript code
    vbs_code = f"""
    Dim objShell
    Set objShell = CreateObject("WScript.Shell")
    objShell.Popup "{clean_content}", 0, "{clean_title}", {vbs_icon_value}
    """
    
    # Execute the VBScript using your pywiner.system module
    exec_vbs(vbs_code)

if __name__ == '__main__':
    # This is a basic test. For a real test, you should publish the library first.
    
    # Test 1: Information message box
    msgbox(
        icon="information",
        title="Welcome",
        content="This is an information message from Pywiner!"
    )

    # Test 2: Warning message box
    msgbox(
        icon="warning",
        title="Attention!",
        content="This is a warning message."
    )
    
    # Test 3: Critical message box
    msgbox(
        icon="critical",
        title="Error!",
        content="This is a critical error message."
    )


import sys
from PyQt6.QtWidgets import QApplication, QWidget, QLabel, QPushButton
from PyQt6.QtGui import QPixmap, QFont
from PyQt6.QtCore import Qt, QSize

class HoverableLabel(QLabel):
    def __init__(self, parent, on_enter=None, on_leave=None):
        super().__init__(parent)
        self.on_enter_func = on_enter
        self.on_leave_func = on_leave
        self.setMouseTracking(True)

    def enterEvent(self, event):
        if self.on_enter_func:
            self.on_enter_func()
        super().enterEvent(event)

    def leaveEvent(self, event):
        if self.on_leave_func:
            self.on_leave_func()
        super().leaveEvent(event)

class Window(QWidget):
    def __init__(self, title, width, height, background_color=None):
        super().__init__()
        self.setWindowTitle(title)
        self.resize(width, height)
        self.widgets = []
        
        if background_color:
            self.setStyleSheet(f"background-color: {background_color};")
            
    def add_text(self, text, x=0, y=0, font_size=12, font_family="Arial", color="black", on_hover=None, on_leave=None):
        text_label = HoverableLabel(self, on_enter=on_hover, on_leave=on_leave)
        text_label.setText(text)
        text_label.move(x, y)
        
        font = QFont(font_family, font_size)
        text_label.setFont(font)
        
        text_label.setStyleSheet(f"color: {color};")
        
        text_label.show()
        self.widgets.append(text_label)
        return text_label

    def add_image(self, image_path, x=0, y=0, width=None, height=None, on_hover=None, on_leave=None):
        image_label = HoverableLabel(self, on_enter=on_hover, on_leave=on_leave)
        pixmap = QPixmap(image_path)
        
        if width and height:
            pixmap = pixmap.scaled(QSize(width, height), Qt.AspectRatioMode.KeepAspectRatio)
        
        image_label.setPixmap(pixmap)
        image_label.move(x, y)
        image_label.show()
        self.widgets.append(image_label)
        return image_label
    
    def add_button(self, text, x, y, width=100, height=30, on_click=None):
        button = QPushButton(text, self)
        button.move(x, y)
        button.setFixedSize(width, height)
        
        if on_click:
            button.clicked.connect(on_click)
            
        button.show()
        self.widgets.append(button)
        return button

    def run(self):
        self.show()

if __name__ == '__main__':
    app = QApplication(sys.argv)
    
    my_window = Window(
        title="Complete Pywiner Window",
        width=800,
        height=600,
        background_color="lightgray"
    )
    
    my_window.add_text(
        text="Hello, Pywiner World!",
        x=50,
        y=50,
        font_size=20,
        font_family="Comic Sans MS",
        color="blue"
    )
    
    my_window.add_image(
        image_path="logo.png",
        x=200,
        y=200,
        width=200,
        height=200
    )

    my_window.run()
    sys.exit(app.exec())


import os
import shutil
import subprocess
import tempfile
import time
import threading

def list_processes():
    output = subprocess.check_output("tasklist /fo csv /nh", shell=True, text=True)
    processes = []
    for line in output.strip().split('\n'):
        parts = line.split(',')
        if len(parts) > 0:
            processes.append(parts[0].strip().strip('"'))
    return processes

def find_process(name):
    output = subprocess.check_output(f"tasklist /fo csv /nh /fi \"imagename eq {name}\"", shell=True, text=True)
    if output.strip():
        parts = output.strip().split(',')
        if len(parts) > 1:
            try:
                return int(parts[1].strip().strip('"'))
            except (ValueError, IndexError):
                pass
    return None

def kill_process(pid):
    try:
        subprocess.run(f"taskkill /F /PID {pid}", check=True, shell=True)
        return True
    except subprocess.CalledProcessError:
        return False

def start_command(command, shell=True):
    subprocess.Popen(command, shell=shell)

def start(exe_path, args=None):
    if args is None:
        args = []
    subprocess.Popen([exe_path] + args)

def exec_batch(batch_code):
    try:
        with tempfile.NamedTemporaryFile(mode='w', delete=False, suffix='.bat') as temp_file:
            temp_file.write(batch_code)
            temp_batch_path = temp_file.name
        
        subprocess.run(temp_batch_path, shell=True)
    
    finally:
        if os.path.exists(temp_batch_path):
            os.remove(temp_batch_path)

def exec_vbs(vbs_code):
    try:
        with tempfile.NamedTemporaryFile(mode='w', delete=False, suffix='.vbs') as temp_file:
            temp_file.write(vbs_code)
            temp_vbs_path = temp_file.name

        subprocess.run(["wscript.exe", temp_vbs_path], check=True)
    
    finally:
        if os.path.exists(temp_vbs_path):
            os.remove(temp_vbs_path)

def delete_file(filepath):
    try:
        os.remove(filepath)
        return True
    except FileNotFoundError:
        print(f"Error: The file '{filepath}' was not found.")
        return False
    except Exception as e:
        print(f"Error trying to delete file '{filepath}': {e}")
        return False

def create_file(filepath, content):
    try:
        with open(filepath, 'w', encoding='utf-8') as f:
            f.write(content)
        return True
    except Exception as e:
        print(f"Error trying to create file: {e}")
        return False

def read_file(filepath):
    try:
        with open(filepath, 'r', encoding='utf-8') as f:
            return f.read()
    except FileNotFoundError:
        print(f"Error: The file '{filepath}' was not found.")
        return None
    except Exception as e:
        print(f"Error trying to read file '{filepath}': {e}")
        return None

def create_directory(path):
    try:
        os.makedirs(path, exist_ok=True)
        return True
    except Exception as e:
        print(f"Error creating directory '{path}': {e}")
        return False

def delete_directory(path):
    try:
        shutil.rmtree(path)
        return True
    except FileNotFoundError:
        return False
    except Exception as e:
        print(f"Error deleting directory '{path}': {e}")
        return False

def while_process_running(process_name):
    while find_process(process_name) is not None:
        time.sleep(1)

def while_process_not_running(process_name):
    while find_process(process_name) is None:
        time.sleep(1)

def _monitor_process_death(process_name, callback):
    while find_process(process_name):
        time.sleep(1)
    callback()

def on_process_died(process_name, callback):
    monitor_thread = threading.Thread(target=_monitor_process_death, args=(process_name, callback), daemon=True)
    monitor_thread.start()

def _monitor_process_start(process_name, callback):
    while find_process(process_name) is None:
        time.sleep(1)
    callback()

def on_process_started(process_name, callback):
    monitor_thread = threading.Thread(target=_monitor_process_start, args=(process_name, callback), daemon=True)
    monitor_thread.start()